#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-FSi8Gz8vNqdGp67LQVBK74
key:                  coinbase-pro-0.9.3.2-FSi8Gz8vNqdGp67LQVBK74
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  7a83d199df8fe049c84e01511a27e2bc
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-FSi8Gz8vNqdGp67LQVBK74
depends:
    HsOpenSSL-0.11.7.10-3hAwRMZRL2yGQzd1MdjCmg
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    aeson-casing-0.2.0.0-FJsvSnNXEBV69SkXuuevXg
    async-2.2.6-5xQ7XDEe3v3DeLHeJRStgT base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9vIe4KhYz6AEokdeiWpGU exceptions-0.10.7
    http-api-data-0.6.1-B4xD2REm6ADDTbBWwdbcen
    http-client-0.7.19-DXRmxPRORBE3MdmQmSy3IG
    http-client-tls-0.3.6.4-HN3tMmJV0pX8jUBu7FQeO5
    http-streams-0.8.9.9-59EeV4pIsXa1ZUhHgbyJZI
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    io-streams-1.5.2.2-Dd6n5yqwWQWLI8pGaNDCZh
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-5wCX3hTprFv2vYcKA8r7kN
    servant-0.20.3.0-HxJc4HNE5VN5ggSNE5tRj0
    servant-client-0.20.3.0-Jf3sP9ohRSgGokK7YuaAMt
    servant-client-core-0.20.3.0-3XpCQ6St3rw55CPHyuw9xQ
    tasty-1.5.3-Exj5fOeuSOhFgSXZfzsDUq
    tasty-hunit-0.10.2-Kw5cfkeTKbS2vHBXEHB5Hj text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-57SVybgQXxVCaWJKdwo5xH
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    uuid-1.3.16.1-5nBx1zqzMyABYgSGjQK07L
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV
    websockets-0.12.7.3-ABWsPo2gyEZ9WnaaZ7Peoi
    wuss-2.0.1.7-HaPh5fIJgB59dpwQwtr3RM

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

